
HonkV2 = {};
source("dataS/scripts/vehicles/specializations/HonkEvent.lua");

function HonkV2.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function HonkV2:load(xmlFile)
	self.playHonkV2 = SpecializationUtil.callSpecializationsFunction("playHonkV2");
	local HonkV2SoundFile = getXMLString(xmlFile, "vehicle.HonkLoopSound#file");
	local clientHonkV2SoundFile = getXMLString(xmlFile, "vehicle.HonkLoopSound#client");
	if clientHonkV2SoundFile == nil then
		clientHonkV2SoundFile = HonkV2SoundFile;
	end;
	if HonkV2SoundFile ~= nil then
		HonkV2SoundFile = Utils.getFilename(HonkV2SoundFile, self.baseDirectory);
		clientHonkV2SoundFile = Utils.getFilename(clientHonkV2SoundFile, self.baseDirectory);
		self.HonkV2SoundId = createSample("HonkV2Sound");
		loadSample(self.HonkV2SoundId, HonkV2SoundFile, false);
		self.HonkV2SoundVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.HonkLoopSound#volume"), 1.0);
		self.HonkV2SoundRadius = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.HonkLoopSound#radius"), 50);
		self.HonkV2SoundInnerRadius = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.HonkLoopSound#innerRadius"), 10);
		self.clientHonkV2Sound = createAudioSource("clientHonkV2Sound", clientHonkV2SoundFile, self.HonkV2SoundRadius, self.HonkV2SoundInnerRadius, self.HonkV2SoundVolume, 0);
		link(self.components[1].node, self.clientHonkV2Sound);
		setVisibility(self.clientHonkV2Sound, false);
		self.HonkV2Playing = false;
	end;
end;

function HonkV2:delete()
	if self.HonkV2SoundId ~= nil then
		delete(self.HonkV2SoundId);
		self.HonkV2SoundId = nil;
	end;
end;

function HonkV2:readStream(streamId, connection)
end;

function HonkV2:writeStream(streamId, connection)
end;

function HonkV2:mouseEvent(posX, posY, isDown, isUp, button)
end;

function HonkV2:keyEvent(unicode, sym, modifier, isDown)
end;

function HonkV2:update(dt)
	if self.isEntered and self.isClient and self:getIsActiveForInput(false) then
		if self.HonkV2SoundId ~= nil then
			if InputBinding.hasEvent(InputBinding.HonkV2) then
				self:playHonkV2(not self.HonkV2Playing);
			end;
		end;
	end;
end;

function HonkV2:updateTick(dt)
end;

function HonkV2:draw()                            
end;

function HonkV2:onLeave()                            
end;

function HonkV2:onDetach()
	if self.HonkV2SoundId ~= nil then
		setVisibility(self.clientHonkV2Sound, false);
		stopSample(self.HonkV2SoundId);
	end;
end;

function HonkV2:playHonkV2(isPlaying, noEventSend)
	if self.HonkV2SoundId ~= nil then
		HonkEvent.sendEvent(self, isPlaying, noEventSend);
		self.HonkV2Playing = isPlaying;
		if isPlaying then
			if self:getIsActive() then
				if self:getIsActiveForSound() then
					playSample(self.HonkV2SoundId, 0, self.HonkV2SoundVolume, 0);
				elseif self.isControlled then
					setVisibility(self.clientHonkV2Sound, true);
				end;
			end;
		else
			stopSample(self.HonkV2SoundId);
			setVisibility(self.clientHonkV2Sound, false);
		end;
	end;
end;
